@@ -37,8 +37,9 @@ describe 'ceilometer::agent::notification' do
     it { is_expected.to contain_class('ceilometer::params') }
 
     it 'installs ceilometer agent notification package' do
-      is_expected.to contain_package(platform_params[:agent_notification_package_name]).with(
+      is_expected.to contain_package('ceilometer-notification').with(
         :ensure => 'present',
+        :name   => platform_params[:agent_notification_package_name],
         :tag    => ['openstack', 'ceilometer-package'],
       )
     end
@@ -66,7 +67,7 @@ describe 'ceilometer::agent::notification' do
 
         it 'configures ceilometer agent notification service' do
           is_expected.to contain_service('ceilometer-agent-notification').with(
-            :ensure     => (params[:manage_service] && params[:enabled]) ? 'running' : 'stopped',
+            :ensure     => params[:enabled] ? 'running' : 'stopped',
             :name       => platform_params[:agent_notification_service_name],
             :enable     => params[:enabled],
             :hasstatus  => true,
@@ -77,22 +78,13 @@ describe 'ceilometer::agent::notification' do
       end
     end
 
-    context 'with disabled service managing' do
+    context 'with service unmanaged' do
       before do
-        params.merge!({
-          :manage_service => false,
-          :enabled        => false })
+        params.merge!({ :manage_service => false })
       end
 
       it 'configures ceilometer-agent-notification service' do
-        is_expected.to contain_service('ceilometer-agent-notification').with(
-          :ensure     => nil,
-          :name       => platform_params[:agent_notification_service_name],
-          :enable     => false,
-          :hasstatus  => true,
-          :hasrestart => true,
-          :tag        => 'ceilometer-service'
-        )
+        is_expected.to_not contain_service('ceilometer-agent-notification')
       end
     end
 
@@ -262,6 +254,14 @@ sinks:
         it { is_expected.not_to contain_file('pipeline') }
     end
 
+    context 'with workers' do
+      before do
+        params.merge!( :workers => 4 )
+      end
+
+      it { is_expected.to contain_ceilometer_config('notification/workers').with_value(4) }
+    end
+
     context 'with custom ack_on_event_error' do
       before do
         params.merge!( :ack_on_event_error => true )
