@@ -48,7 +48,6 @@ describe 'ceilometer::agent::polling' do
         :tag        => 'ceilometer-service',
       )}
 
-      it { should_not contain_ceilometer_config('coordination/backend_url') }
       it { should_not contain_file('polling') }
     end
 
@@ -79,14 +78,13 @@ describe 'ceilometer::agent::polling' do
       it { should contain_ceilometer_config('DEFAULT/polling_namespaces').with_value('compute') }
     end
 
-    context 'with disabled service managing' do
+    context 'with service disabled' do
       before do
-        params.merge!( :manage_service => false,
-                       :enabled        => false )
+        params.merge!( :enabled => false )
       end
 
       it { should contain_service('ceilometer-polling').with(
-        :ensure     => nil,
+        :ensure     => 'stopped',
         :name       => platform_params[:agent_service_name],
         :enable     => false,
         :hasstatus  => true,
@@ -95,6 +93,14 @@ describe 'ceilometer::agent::polling' do
       )}
     end
 
+    context 'with service unmanaged' do
+      before do
+        params.merge!( :manage_service => false )
+      end
+
+      it { should_not contain_service('ceilometer-polling') }
+    end
+
     context 'with polling management enabled and default meters' do
       before do
         params.merge!( :manage_polling => true )
@@ -115,14 +121,21 @@ sources:
         - network.incoming.packets
         - network.outgoing.bytes
         - network.outgoing.packets
-        - disk.read.bytes
-        - disk.read.requests
-        - disk.write.bytes
-        - disk.write.requests
+        - disk.device.read.bytes
+        - disk.device.read.requests
+        - disk.device.write.bytes
+        - disk.device.write.requests
         - volume.size
         - volume.snapshot.size
         - volume.backup.size
         - hardware.cpu.util
+        - hardware.cpu.user
+        - hardware.cpu.nice
+        - hardware.cpu.system
+        - hardware.cpu.idle
+        - hardware.cpu.wait
+        - hardware.cpu.kernel
+        - hardware.cpu.interrupt
         - hardware.memory.used
         - hardware.memory.total
         - hardware.memory.buffer
